
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <string.h>

#include <X11/xv/xvCore.h>
#include <X11/xv/xvRegion.h>
#include <X11/xv/xvGC.h>
#include <X11/xv/xvGraphic.h>

// -----------------------------------

xvGraphic::xvGraphic()
{
}

// -----------------------------------

xvGraphic::~xvGraphic()
{
}

// -----------------------------------

void xvGraphic::init(xvCore & object)
{
	xvGC::init(object);
}

// -----------------------------------

void xvGraphic::init(Widget wid)
{
	xvGC::init(wid);
}

// -----------------------------------

void xvGraphic::GClearArea(int x, int y, unsigned int width, unsigned int height, Boolean exposures)
{
	XClearArea(xvdisplay, xvwindow, x, y, width, height, exposures);
}

// ------------------------------------

void xvGraphic::GClearWindow()
{
	XClearWindow(xvdisplay, xvwindow);
}

// -------------------------------------

void xvGraphic::GCopyArea(xvGC & dest, int sx, int sy, unsigned int width, unsigned int height,
				int dx, int dy)

{
	XCopyArea(xvdisplay, xvwindow, dest.WinID(), xvcontext, sx, sy, width, height, 
				dx, dy);
}

// --------------------------------------

void xvGraphic::GCopyPlane(xvGC & dest, int sx, int sy, unsigned int width, unsigned int height,
				int dx, int dy, unsigned long plane)
{
	XCopyPlane(xvdisplay, xvwindow, dest.WinID(), xvcontext, sx, sy, width, height, 
				dx, dy, plane);
}

// ----------------------------------------

void xvGraphic::GDrawPoint(int x, int y)
{
	XDrawPoint(xvdisplay, xvwindow, xvcontext, x, y);
}

// ----------------------------------------

void xvGraphic::GDrawPoints(XPoint *points, int npoints, int mode)
{
	XDrawPoints(xvdisplay, xvwindow, xvcontext, points, npoints, mode);
}

// -----------------------------------------

void xvGraphic::GDrawLine(int x1, int y1, int x2, int y2)
{
	XDrawLine(xvdisplay, xvwindow, xvcontext, x1, y1, x2, y2);
}

// -----------------------------------------

void xvGraphic::GDrawLines(XPoint *points, int npoints, int mode)
{
	XDrawLines(xvdisplay, xvwindow, xvcontext, points, npoints, mode);
}

// -----------------------------------------

void xvGraphic::GDrawSegments(XSegment *segments, int nseg)
{
	XDrawSegments(xvdisplay, xvwindow, xvcontext, segments, nseg);
}
		
// -----------------------------------

void xvGraphic::GDrawRectangle(int x, int y, unsigned int width, unsigned int height)
{
	XDrawRectangle(xvdisplay, xvwindow, xvcontext, x, y, width, height);
}

// ------------------------------------

void xvGraphic::GDrawRectangles(XRectangle rectangles[], int nrect)
{
	XDrawRectangles(xvdisplay, xvwindow, xvcontext, rectangles, nrect);
}

// -------------------------------------
	
void xvGraphic::GDrawArc(int x, int y, unsigned int width, unsigned int height,
					int angle1, int angle2)
{
	XDrawArc(xvdisplay, xvwindow, xvcontext, x, y, width, height, angle1, angle2);
}

// -------------------------------------

void xvGraphic::GDrawArcs(XArc *arcs, int narcs)
{
	XDrawArcs(xvdisplay, xvwindow, xvcontext, arcs, narcs);
}

// --------------------------------------

void xvGraphic::GFillRectangle(int x, int y, unsigned int width, unsigned int height)
{
	XFillRectangle(xvdisplay, xvwindow, xvcontext, x, y, width, height);
}

// --------------------------------------

void xvGraphic::GFillRectangles(XRectangle *rectangles, int nrect)
{
	XFillRectangles(xvdisplay, xvwindow, xvcontext, rectangles, nrect);
}

// ---------------------------------------

void xvGraphic::GFillPolygon(XPoint *points, int npoints, int shape, int mode)
{
	XFillPolygon(xvdisplay, xvwindow, xvcontext, points, npoints, shape, mode);
}

// ----------------------------------------

void xvGraphic::GFillArc(int x, int y, unsigned int width, unsigned int height, 
					int angle1, int angle2)
{
	XFillArc(xvdisplay, xvwindow, xvcontext, x, y, width, height, angle1, angle2);
}

// ------------------------------------------

void xvGraphic::GFillArcs(XArc *arcs, int narcs)
{
	XFillArcs(xvdisplay, xvwindow, xvcontext, arcs, narcs);
}

// ------------------------------------------

void xvGraphic::GPrint(int x, int y, String message)
{
	XDrawString(xvdisplay, xvwindow, xvcontext, x, y, message, strlen(message));
}

// ------------------------------------------

void xvGraphic::GPrintImage(int x, int y, String message)
{
	XDrawImageString(xvdisplay, xvwindow, xvcontext, x, y, message, strlen(message));
}

// ------------------------------------------

XImage *xvGraphic::GGetImage(int x, int y, unsigned int width, unsigned int height,
				unsigned long plane_mask, int format)
{
	gimage=XGetImage(xvdisplay, xvwindow, x, y, width, height, plane_mask, format);	
	return(gimage);
}

// -------------------------------------------

XImage *xvGraphic::GGetSubImage(int x, int y, unsigned int width, unsigned int height,
					unsigned long plane_mask, int format, 
					int dx, int dy, XImage *image=NULL)
{
	XImage *temp=image;
	if (temp==NULL)
		temp=gimage;
	temp=XGetSubImage(xvdisplay, xvwindow, x, y, width, height, plane_mask, format,
					temp, dx, dy);
	return(temp);
}

// -------------------------------------------

void xvGraphic::GPutImage(int sx, int sy, int dx, int dy, unsigned int width, unsigned int height,
				XImage *image)
{
	XImage *temp=image;
	if (temp==NULL)
		temp=gimage;
	XPutImage(xvdisplay, xvwindow, xvcontext, temp, sx, sy, dx, dy, width, height);
}

// --------------------------------------------

