
/*     *******************************************************************************
	XVisual GUI Development System for Linux/X-Window
	Copyright (C) 1996 Steve Carrie.

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2 of the License, or
        (at your option) any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
        ******************************************************************************* */

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Xaw/Command.h>

#include <X11/xv/xvCore.h>
#include <X11/xv/xvBasicBitmap.h>
#include <X11/xv/xvFont.h>
#include <X11/xv/xvPopupShell.h>
#include <X11/xv/xvForm.h>
#include <X11/xv/xvLabel.h>
#include <X11/xv/xvButton.h>
#include <X11/xv/xvMsgBox.h>
#include <X11/xv/stop.xbm>
#include <X11/xv/warn.xbm>
#include <X11/xv/query.xbm>

// ---------------------------------------------

xvMsgBox::xvMsgBox()
{
	result=0;
}

// ---------------------------------------------

xvMsgBox::xvMsgBox(String name, xvCore & parent, String message, 
			int type, String back,
			XtCallbackProc b1_call, XtCallbackProc b2_call)
{
	result=0;
	init(name, parent, message, type, back, b1_call, b2_call);
}

// ---------------------------------------------

xvMsgBox::~xvMsgBox()
{
}

// ---------------------------------------------

void xvMsgBox::init(String name, xvCore & parent, String message, 
			int type, String back,
			XtCallbackProc b1_call, XtCallbackProc b2_call)
{
	backcolor=back;
	xvPopupShell::init(name, parent);
	
	msgform.init(name, xvPopupShell::ID(), FALSE, TRUE);
	msgform.SetBackground(backcolor);

	msgicon.init(" ", msgform);
	msgicon.SetVertDistance(25);
	msgicon.SetHorizDistance(25);
	msgicon.SetBorderWidth(0);
	msgicon.SetShadowWidth(4);
	msgicon.SetBeNiceToColormap(FALSE);
	msgicon.SetBackground(backcolor);

	msglabel.init(message, msgform);
	msglabel.SetRelHorizontal(msgicon);
	msglabel.SetVertDistance(50);
	msglabel.SetHorizDistance(15);
	msglabel.SetBorderWidth(0);
	msglabel.SetJustify(XtJustifyCenter);
	msglabel.SetBackground(backcolor);
	msglabel.ChangeFont("*times-*-r-*-140*");

	switch(type) {
		case XVMSGSIMPLEWARN:
			msgicon.SetBitmapInfo(warn_bits, warn_width, warn_height, XtNbitmap);

			b1.init("OK", msgform, b1_call);
			b1.SetRelVertical(msgicon);
			b1.SetVertDistance(25);
			b1.SetWidth(b1.GetWidth()*2);
			b1.SetHeight(b1.GetHeight()*2);
			b1.SetResource(XtNshapeStyle, XmuShapeRoundedRectangle);
			b1.ChangeFont("*times-*-r-*-140*");
			b1.SetBeNiceToColormap(FALSE);
			break;
		case XVMSGSIMPLEFATAL:
			msgicon.SetBitmapInfo(stop_bits, stop_width, stop_height, XtNbitmap);

			b1.init("OK", msgform, b1_call);
			b1.SetRelVertical(msgicon);
			b1.SetVertDistance(25);
			b1.SetWidth(b1.GetWidth()*2);
			b1.SetHeight(b1.GetHeight()*2);
			b1.SetResource(XtNshapeStyle, XmuShapeRoundedRectangle);
			b1.ChangeFont("*times-*-r-*-140*");
			b1.SetBeNiceToColormap(FALSE);
			break;
		case XVMSGSIMPLECHOICE:
			msgicon.SetBitmapInfo(query_bits, query_width, query_height, XtNbitmap);
			
			b1.init("YES", msgform, b1_call);
			b1.SetRelVertical(msgicon);
			b1.SetVertDistance(25);
			b1.SetResource(XtNshapeStyle, XmuShapeRoundedRectangle);
			b1.ChangeFont("*times-*-r-*-140*");
			b1.SetBeNiceToColormap(FALSE);

			b2.init("NO", msgform, b2_call);
			b2.SetRelVertical(msgicon);
			b2.SetVertDistance(25);
			b2.SetResource(XtNshapeStyle, XmuShapeRoundedRectangle);
			b2.ChangeFont("*times-*-r-*-140*");
			b2.SetBeNiceToColormap(FALSE);
			break;
	}

	spr.init(" ", msgform);
	spr.SetRelHorizontal(msglabel);
	spr.SetBorderWidth(0);
	spr.SetHorizDistance(5);
	spr.SetVertDistance(25);
	spr.SetBackground(backcolor);

	switch(type) {
		case XVMSGSIMPLEFATAL:
		case XVMSGSIMPLEWARN:
			b1.SetHorizDistance(msgform.GetWidth()/2-b1.GetWidth()/2);
			break;
		case XVMSGSIMPLECHOICE:
			b1.SetHorizDistance((int) msgform.GetWidth()/3);
			b2.SetHorizDistance((int) msgform.GetWidth()/3*2);
			break;
	}
	msgform.ManageChildren(TRUE);
}

// ---------------------------------------------

void xvMsgBox::ChangeFont(String fontname)
{
	msglabel.ChangeFont(fontname);
	b1.ChangeFont(fontname);
	b2.ChangeFont(fontname);
}

// ----------------------------------------------
	